package game

type char byte
type MapColor [3]int

type Level struct {
    Branch string
    Exits  []string
    Rooms  []string
    Map    LevelMap
    Mobs   []*Mob
}


func (level *Level) Remove (mob *Mob) bool {
    return DeleteFromMobSlice(level.Mobs, mob)
}

type LevelMap struct {
    SizeX    int
    SizeY    int
    Geometry [][]Tile
}

type Tile struct {
    Glyph    *TileGlyph
    Explored bool
    IsSafe   bool
    MustDraw bool
}

// Graphical representation of tile's glyph
type TileGlyph struct {
    Char        char
    FgColor     MapColor
    BgColor     MapColor
    DarkFgColor MapColor
    DarkBgColor MapColor
    ColorDance  bool
    BlocksPass  bool
    BlocksSight bool
    WaterTight  bool
    GasTight    bool
}


func DeleteFromMobSlice (slice []*Mob, item *Mob) bool {
    for i := range slice {
        if slice[i].name == item.name && slice[i].id == item.id {
            copy(slice[i:], slice[i+1:])
            slice[len(slice)-1] = nil
            slice = slice[:len(slice)-1]
            return true
        }
    }
    return false
}

func DeleteFromItemSlice (slice []*Item, item *Item) bool {
    for i := range slice {
        if slice[i].name == item.name && slice[i].id == item.id {
            copy(slice[i:], slice[i+1:])
            slice[len(slice)-1] = nil
            slice = slice[:len(slice)-1]
            return true
        }
    }
    return false
}